

// The JDK
import java.sql.*;
import javax.sql.*;
import javax.naming.*;
import java.util.Hashtable;

/**
 * This simple tool executes a test of a bound DataSource
 * object. Notice that it doesn't import the PoolMan libraries
 * and doesn't need to reference PoolMan directly, as this
 * is all just JDBC 2.0 standard stuff.
 */
public class DataSourceTest {

    public static void main(String args[]) {
	
	if (args.length < 2) {
	    printSyntax();
	    System.exit(1);
	}
	
	String jndiName = args[0];
	String sqlstring = args[1];
	String host = "localhost";
	String port = "1099";

	if (args.length > 2)
	    host = args[2];
	if (args.length > 3)
	    port = args[3];

	try {
	    
	    // JNDI
	    Hashtable env = new Hashtable();
	    env.put(Context.INITIAL_CONTEXT_FACTORY,
		    "com.sun.jndi.rmi.registry.RegistryContextFactory");
	    env.put(Context.PROVIDER_URL, "rmi://" + host + ":" + port);
	    env.put("java.naming.rmi.security.manager", "1");
	    Context ctx = new InitialContext(env);

	    // TEST GETTING THE CONNECTION
	    DataSource ds = (DataSource) ctx.lookup(jndiName);
	    Connection con = null;
	    try {
		con = ds.getConnection();
		System.out.println("Got Connection, executing SQL...");

		// TEST USING THE CONNECTION
		Statement st = con.createStatement();
		ResultSet res = st.executeQuery(sqlstring);
		ResultSetMetaData meta = res.getMetaData();
		int cols = meta.getColumnCount();
		System.out.print("\n");
		while (res.next()) {
		    for (int i=1; i<=cols; i++) {
			System.out.print("\t" + meta.getColumnLabel(i) + ": " +
					 res.getObject(i).toString());
		    }
		    System.out.print("\n");
		}
		res.close(); st.close();
	    } catch (Exception e) {
		System.out.println("Error while executing SQL:\n");
		e.printStackTrace();
	    }
	    finally {
		if (con != null) 
		    con.close();
		
	    }
	} catch (javax.naming.ServiceUnavailableException se) {
	    System.out.println("\nERROR: Unable to connect to the remote JNDI tree. " +
			       "Have you started JNDI? "+
			       "Try using the DeployDataSource tool.\n");
	} catch (Exception e) {
	    e.printStackTrace(); 
	}

	System.out.print("\n");
	System.exit(0);
    }
    
    public static void printSyntax() {
	System.out.println("\nUSAGE: " +
			   "java -Djava.security.policy=poolman.policy " +
			   "DataSourceTest [jndiName of the DataSource] " +
			   "[SQL statement] [host (optional)] [port (optional)]\n");
	System.out.println("EXAMPLE: java -Djava.security.policy=poolman.policy " +
			   "DataSourceTest \"mySQL\" \"select * from users\"\n");
    }

}
