
// Code Studio
import com.codestudio.sql.*;

// The JDK
import java.sql.*;
import javax.sql.*;
import javax.naming.*;
import java.util.Hashtable;
import java.rmi.registry.*;

/**
 * This simple tool is a working example of how PoolManDataSource
 * might be bound to a JNDI resource. In this case, Sun's rmiregistry
 * JNDI service provider is used.
 * <br>
 * Start the rmiregistry before executing this code.
 * <br>
 * USAGE: java -Djava.security.policy=poolman.policy DeployDataSource [options]
 */
public class DeployDataSource {

    public static void main(String args[]) {

	if (args.length < 1) {
	    printSyntax();
	    System.exit(1);
	}

	String dbname = args[0];

	String serverport = "1099";
	if (args.length > 1)
	    serverport = args[1];

	String port = null;
	if (args.length > 2)
	    port = args[2];

	String host = "localhost";
	String description = "PoolMan DataSource for " + dbname;
	if (args.length > 3)
	    description = args[3];

	String jndiName = dbname;
	String ctxURL = "rmi://" + host;
	if (serverport != null)
	    ctxURL += ":" + serverport;

	// START THE REGISTRY IF NECESSARY
	try {
	    Registry reg = null;
	    reg = LocateRegistry.createRegistry(Integer.parseInt(serverport));
	    System.out.println("Started Registry...");
	} catch (Exception e) {}

	try {

	    // CREATE THE DATASOURCE
	    com.codestudio.sql.PoolManDataSource poolman = new com.codestudio.sql.PoolManDataSource();
	    poolman.setDatabaseName(dbname);
	    poolman.setDescription(description);
	    
	    // JNDI
	    Hashtable env = new Hashtable();
	    env.put(Context.INITIAL_CONTEXT_FACTORY,
		    "com.sun.jndi.rmi.registry.RegistryContextFactory");
	    env.put(Context.PROVIDER_URL, ctxURL);
	    env.put("java.naming.rmi.security.manager", "1");
	    Context ctx = new InitialContext(env);

	    // BIND THE DATASOURCE	
	    ctx.rebind(jndiName, poolman);
	    System.out.println("\nSUCCESS: PoolManDataSource Deployed on " + host + ":" + serverport + 
			       " under the name \"" + jndiName + "\"\n");
	    System.out.println("To test connectivity to this DataSource, execute the following:\n"+
			       "java -Djava.security.policy=poolman.policy DataSourceTest " +
			       "\"" + jndiName + "\" \"[SQL statement for your db]\" " + " " +
			       host + " " + serverport + "\n");
	
	} catch (Exception e) { e.printStackTrace(); }

    }

    public static void printSyntax() {
	System.out.println("\nUSAGE: "+
			   "java -Djava.security.policy=poolman.policy DeployDataSource " +
			   "[dbname] [serverport (optional)] [port (optional)] " +
			   "[description of the DataSource (optional)]\n");
        System.out.println("EXAMPLE: java -Djava.security.policy=poolman.policy DeployDataSource mySQL\n");
    }

}
